==> MySQLDumper1.24.2.zip: msd1.24.2/language/it/lang_sql.php <==
<?php
$lang['L_COMMAND']="comando";
$lang['L_IMPORT_NOTABLE']="Non è stato scelta nessuna tabella per l`importazione!";
$lang['L_PASSWORD_STRENGTH']="Password strength";
$lang['L_SQL_WARNING']="L`esucuzione di comandi SQL potrebbe modificare i dati. L`autore non si prende alcuna responsabilità riguarda la perdita di questi dati.";
$lang['L_SQL_EXEC']="Eseguire comandi SQL";
$lang['L_SQL_DATAVIEW']="Visualizzare dati";
$lang['L_SQL_TABLEVIEW']="Riepilogo tabelle";
$lang['L_SQL_VONINS']="di totale";
$lang['L_SQL_NODATA']="nessun record";
$lang['L_SQL_RECORDUPDATED']="Record è stato cambiato";
$lang['L_SQL_RECORDINSERTED']="Record è stato salvato";
$lang['L_SQL_BACKDBOVERVIEW']="torna dal Riepilogo database";
$lang['L_SQL_RECORDDELETED']="Record è stato cancellato";
$lang['L_ASKTABLEEMPTY']="Vuoi svuotare la tabella `%s` ?";
$lang['L_SQL_RECORDEDIT']="edit record";
$lang['L_SQL_RECORDNEW']="inserire nuovo record";
$lang['L_ASKDELETERECORD']="Vuoi cancellare questo record?";
$lang['L_ASKDELETETABLE']="Vuoi cancellare la tabella `%s` ?";
$lang['L_SQL_BEFEHLE']="Comandi-SQL";
$lang['L_SQL_BEFEHLNEU']="nuovo comando";
$lang['L_SQL_BEFEHLSAVED1']="Comando-SQL";
$lang['L_SQL_BEFEHLSAVED2']="è stato aggiunto";
$lang['L_SQL_BEFEHLSAVED3']="è stato salvato";
$lang['L_SQL_BEFEHLSAVED4']="è stato spostato sopra";
$lang['L_SQL_BEFEHLSAVED5']="è stato cancellato";
$lang['L_SQL_QUERYENTRY']="La query contiene";
$lang['L_SQL_COLUMNS']="Colonne";
$lang['L_ASKDBDELETE']="Vuoi cancellare questo database `%s` con tutto il suo contenuto?";
$lang['L_ASKDBEMPTY']="Vuoi svuotare veramente il database `%s` ?";
$lang['L_ASKDBCOPY']="Vuoi copiare il contenuto di questo database `%s` nel database `%s`?";
$lang['L_SQL_TABLENEW']="Edit tabella";
$lang['L_SQL_OUTPUT']="Output SQL";
$lang['L_DO_NOW']="esegui ora";
$lang['L_SQL_NAMEDEST_MISSING']="Nome del database di destinazione mancante!";
$lang['L_ASKDELETEFIELD']="Vuoi cancellare questo campo?";
$lang['L_SQL_COMMANDS_IN']=" riga in ";
$lang['L_SQL_COMMANDS_IN2']="  sec. parsed.";
$lang['L_SQL_OUT1']="Eseguito";
$lang['L_SQL_OUT2']="Comandi";
$lang['L_SQL_OUT3']="C'erano";
$lang['L_SQL_OUT4']="Commenti";
$lang['L_SQL_OUT5']="Poiché il risultato contiene piu di 5000 righe, queste non sono visibili.";
$lang['L_SQL_SELECDB']="Seleziona database";
$lang['L_SQL_TABLESOFDB']="Tabelle del database";
$lang['L_SQL_EDIT']="edit";
$lang['L_SQL_NOFIELDDELETE']="Impossibile cancellare perchè una tabella deve avere almeno un campo.";
$lang['L_SQL_FIELDDELETE1']="Il campo";
$lang['L_SQL_DELETED']="è stato cancellato";
$lang['L_SQL_CHANGED']="è stato cambiato.";
$lang['L_SQL_CREATED']="è stato creato.";
$lang['L_SQL_NODEST_COPY']="Senza destinazione non si può copiare!";
$lang['L_SQL_DESTTABLE_EXISTS']="Tabella di destinazione già esistente!";
$lang['L_SQL_SCOPY']="La struttura della tabella `%s` e stata copiata in `%s`.";
$lang['L_SQL_TCOPY']="La tabella `%s` è stata copiata con dati in tabella `%s`.";
$lang['L_SQL_TABLENONAME']="La tabella ha bisogno di un nome!";
$lang['L_SQL_TBLNAMEEMPTY']="Il nome della tabella non deve essere vuoto!";
$lang['L_SQL_COLLATENOTMATCH']="Set di caratteri(Charset) ed assortimento(Collation) incompatibili!";
$lang['L_SQL_FIELDNAMENOTVALID']="Errore: nome del campo non valido";
$lang['L_SQL_CREATETABLE']="crea tabella";
$lang['L_SQL_COPYTABLE']="copia tabelle";
$lang['L_SQL_STRUCTUREONLY']="solo struttura";
$lang['L_SQL_STRUCTUREDATA']="Struttura e Dati";
$lang['L_SQL_NOTABLESINDB']="Non ci sono tabelle nel database";
$lang['L_SQL_SELECTTABLE']="Seleziona tabella";
$lang['L_SQL_SHOWDATATABLE']="Guarda dati della tabella";
$lang['L_SQL_TBLPROPSOF']="Proprietà della tabella da";
$lang['L_SQL_EDITFIELD']="Edit campo";
$lang['L_SQL_NEWFIELD']="Nuovo campo";
$lang['L_SQL_INDEXES']="Indice";
$lang['L_SQL_ATPOSITION']="inserire nella posizione";
$lang['L_SQL_FIRST']="prima";
$lang['L_SQL_AFTER']="dopo";
$lang['L_SQL_CHANGEFIELD']="cambia campo";
$lang['L_SQL_INSERTFIELD']="inserisci campo";
$lang['L_SQL_INSERTNEWFIELD']="inserisci nuovo campo";
$lang['L_SQL_TABLEINDEXES']="Indice della tabella";
$lang['L_SQL_ALLOWDUPS']="Duplicati permessi";
$lang['L_SQL_CARDINALITY']="Cardinalità";
$lang['L_SQL_TABLENOINDEXES']="La tabella non contiene l`indice";
$lang['L_SQL_CREATEINDEX']="crea nuovo indice";
$lang['L_SQL_WASEMPTIED']="è stato svuotato";
$lang['L_SQL_RENAMEDTO']="è stato rinominato in";
$lang['L_SQL_DBCOPY']="Il contenuto del database `%s` è stato copiato nel database `%s`.";
$lang['L_SQL_DBSCOPY']="La struttura del database `%s` è stata copiata nel database `%s`.";
$lang['L_SQL_WASCREATED']="stato creato";
$lang['L_SQL_RENAMEDB']="Rinomina database";
$lang['L_SQL_ACTIONS']="Azioni";
$lang['L_SQL_CHOOSEACTION']="Seleziona azione";
$lang['L_SQL_DELETEDB']="Cancella database";
$lang['L_SQL_EMPTYDB']="Svuota database";
$lang['L_SQL_COPYDATADB']="Copia l`intero database in";
$lang['L_SQL_COPYSDB']="Copia struttura in database";
$lang['L_SQL_IMEXPORT']="Importa / Esporta";
$lang['L_INFO_RECORDS']="Record";
$lang['L_NAME']="Nome";
$lang['L_ASKTABLEEMPTYKEYS']="Vuoi svuotare la tabella `%s` e cancellare l`indice?";
$lang['L_EDIT']="edit";
$lang['L_DELETE']="elimina";
$lang['L_EMPTY']="svuota";
$lang['L_EMPTYKEYS']="svuota e cancella l`indice";
$lang['L_SQL_TABLEEMPTIED']="La tabella `%s` e stata svuotata.";
$lang['L_SQL_TABLEEMPTIEDKEYS']="La tabella `%s` è stata svuotata e l`ìndice è stato cancellato.";
$lang['L_SQL_LIBRARY']="SQL-Library";
$lang['L_SQL_ATTRIBUTES']="Attributi";
$lang['L_SQL_UPLOADEDFILE']="File caricato: ";
$lang['L_SQL_IMPORT']="Import del database `%s`";
$lang['L_EXPORT']="Esporta";
$lang['L_IMPORT']="Importa";
$lang['L_IMPORTOPTIONS']="Opzioni di importazione";
$lang['L_CSVOPTIONS']="Opzioni-CSV";
$lang['L_IMPORTTABLE']="Importa nella tabella";
$lang['L_NEWTABLE']="tabella nuova";
$lang['L_IMPORTSOURCE']="Sorgente di importazione";
$lang['L_FROMTEXTBOX']="dal campo testo";
$lang['L_FROMFILE']="dal file";
$lang['L_EMPTYTABLEBEFORE']="Svuota prima la tabella";
$lang['L_CREATEAUTOINDEX']="Creare indice automatico";
$lang['L_CSV_NAMEFIRSTLINE']="nome del campo nella prima riga";
$lang['L_CSV_FIELDSEPERATE']="Campi separati con";
$lang['L_CSV_FIELDSENCLOSED']="Campi inclusi in";
$lang['L_CSV_FIELDSESCAPE']="Campi sfuggiti da";
$lang['L_CSV_EOL']="Linee separate con";
$lang['L_CSV_NULL']="Cambia ZERO con";
$lang['L_CSV_FILEOPEN']="aprire file CSV";
$lang['L_IMPORTIEREN']="importare";
$lang['L_SQL_EXPORT']="Esportazione del database `%s`";
$lang['L_EXPORTOPTIONS']="Opzioni di esportazione";
$lang['L_EXCEL2003']="Excel 2003";
$lang['L_SHOWRESULT']="Visualizzare il risultato";
$lang['L_SENDRESULTASFILE']="Inviare risultato come file";
$lang['L_EXPORTLINES']="<strong>%s</strong> righe da esportare";
$lang['L_CSV_FIELDCOUNT_NOMATCH']="La quantità dei campi della tabella non coincide con i dati da importare (%d al posto di %d).";
$lang['L_CSV_FIELDSLINES']="%d campi trovati, totale %d righe";
$lang['L_CSV_ERRORCREATETABLE']="Errore nella creazione della tabella `%s` !";
$lang['L_FM_UPLOADFILEREQUEST']="Scegli un file.";
$lang['L_CSV_NODATA']="File da importare non trovato!";
$lang['L_SQLLIB_GENERALFUNCTIONS']="funzioni generali";
$lang['L_SQLLIB_RESETAUTO']="ripristina autoincremento";
$lang['L_SQLLIB_BOARDS']="Board";
$lang['L_SQLLIB_DEACTIVATEBOARD']="disattiva Board";
$lang['L_SQLLIB_ACTIVATEBOARD']="attivare Board";
$lang['L_SQL_NOTABLESSELECTED']="Non ci sono tabelle selezionate !";
$lang['L_TOOLS']="Tools";
$lang['L_TOOLS_TOOLBOX']="Scegliere database / Funzione database / Importa e Esporta ";
$lang['L_SQL_OPENFILE']="aprire file - SQL";
$lang['L_SQL_OPENFILE_BUTTON']="Caricare";
$lang['L_MAX_UPLOAD_SIZE']="Grandezza massima del file";
$lang['L_SQL_SEARCH']="Ricerca";
$lang['L_SQL_SEARCHWORDS']="Parola(e) di ricerca";
$lang['L_START_SQL_SEARCH']="esegui ricerca";
$lang['L_RESET_SEARCHWORDS']="resetta ricerca";
$lang['L_SEARCH_OPTIONS']="Opzione di ricerca";
$lang['L_SEARCH_RESULTS']="La ricera di \"<b>%s</b>\" nella tabella \"<b>%s</b>\" ha portato al seguente risultato";
$lang['L_SEARCH_NO_RESULTS']="La ricera \"<b>%s</b>\" nella tabella \"<b>%s</b>\" non ha prodotto risultati!";
$lang['L_NO_ENTRIES']="La tabella \"<b>%s</b>\" è vuota.";
$lang['L_SEARCH_ACCESS_KEYS']="Sfogliare: avanti=ALT+V, indietro=ALT+C";
$lang['L_SEARCH_OPTIONS_OR']="una colonna deve contenere almeno una parola di ricerca";
$lang['L_SEARCH_OPTIONS_CONCAT']="un record deve contenere tutte le parole di ricerca, però possono essere in colonne diverse (Calcolo intensivo!)";
$lang['L_SEARCH_OPTIONS_AND']="una colonna deve contenere tutte le parole di ricerca";
$lang['L_SEARCH_IN_TABLE']="cerca nelle tabelle";
$lang['L_SQL_EDIT_TABLESTRUCTURE']="Edit struttura tabelle";
$lang['L_DEFAULT_CHARSET']="Set di caretteri standard";
$lang['L_TITLE_KEY_PRIMARY']="Chiave primaria";
$lang['L_TITLE_KEY_UNIQUE']="Chiave unica";
$lang['L_TITLE_INDEX']="Indice";
$lang['L_TITLE_KEY_FULLTEXT']="Chiave testo pieno";
$lang['L_TITLE_NOKEY']="Nessuna chiave";
$lang['L_TITLE_SEARCH']="Cerca";
$lang['L_TITLE_MYSQL_HELP']="Documentazione MySQL";
$lang['L_TITLE_UPLOAD']="Carica dati-SQL";
$lang['L_PRIMARYKEY_DELETED']="Chiave primaria cancellata";
$lang['L_PRIMARYKEY_NOTFOUND']="Chiave primaria non trovata";
$lang['L_PRIMARYKEYS_CHANGED']="Chiave primaria cambiata";
$lang['L_PRIMARYKEYS_CHANGINGERROR']="Errore nel cambiare della chiave primaria";
$lang['L_SQL_VIEW_COMPACT']="Visualizza: compatto";
$lang['L_SQL_VIEW_STANDARD']="Visualizza: normale";
$lang['L_FIELDS_OF_TABLE']="Campi della tabella";
$lang['L_ENGINE']="Engine";
$lang['L_USERNAME']="Username";
$lang['L_PASSWORD']="Password";
$lang['L_PASSWORD_REPEAT']="Password (repeat)";


?>

==> MySQLDumper1.24.4.zip: msd1.24.4/language/it/lang_sql.php <==
<?php
$lang['L_COMMAND']="comando";
$lang['L_IMPORT_NOTABLE']="Non è stato scelta nessuna tabella per l`importazione!";
$lang['L_PASSWORD_STRENGTH']="Password strength";
$lang['L_SQL_WARNING']="L`esucuzione di comandi SQL potrebbe modificare i dati. L`autore non si prende alcuna responsabilità riguarda la perdita di questi dati.";
$lang['L_SQL_EXEC']="Eseguire comandi SQL";
$lang['L_SQL_DATAVIEW']="Visualizzare dati";
$lang['L_SQL_TABLEVIEW']="Riepilogo tabelle";
$lang['L_SQL_VONINS']="di totale";
$lang['L_SQL_NODATA']="nessun record";
$lang['L_SQL_RECORDUPDATED']="Record è stato cambiato";
$lang['L_SQL_RECORDINSERTED']="Record è stato salvato";
$lang['L_SQL_BACKDBOVERVIEW']="torna dal Riepilogo database";
$lang['L_SQL_RECORDDELETED']="Record è stato cancellato";
$lang['L_ASKTABLEEMPTY']="Vuoi svuotare la tabella `%s` ?";
$lang['L_SQL_RECORDEDIT']="edit record";
$lang['L_SQL_RECORDNEW']="inserire nuovo record";
$lang['L_ASKDELETERECORD']="Vuoi cancellare questo record?";
$lang['L_ASKDELETETABLE']="Vuoi cancellare la tabella `%s` ?";
$lang['L_SQL_BEFEHLE']="Comandi-SQL";
$lang['L_SQL_BEFEHLNEU']="nuovo comando";
$lang['L_SQL_BEFEHLSAVED1']="Comando-SQL";
$lang['L_SQL_BEFEHLSAVED2']="è stato aggiunto";
$lang['L_SQL_BEFEHLSAVED3']="è stato salvato";
$lang['L_SQL_BEFEHLSAVED4']="è stato spostato sopra";
$lang['L_SQL_BEFEHLSAVED5']="è stato cancellato";
$lang['L_SQL_QUERYENTRY']="La query contiene";
$lang['L_SQL_COLUMNS']="Colonne";
$lang['L_ASKDBDELETE']="Vuoi cancellare questo database `%s` con tutto il suo contenuto?";
$lang['L_ASKDBEMPTY']="Vuoi svuotare veramente il database `%s` ?";
$lang['L_ASKDBCOPY']="Vuoi copiare il contenuto di questo database `%s` nel database `%s`?";
$lang['L_SQL_TABLENEW']="Edit tabella";
$lang['L_SQL_OUTPUT']="Output SQL";
$lang['L_DO_NOW']="esegui ora";
$lang['L_SQL_NAMEDEST_MISSING']="Nome del database di destinazione mancante!";
$lang['L_ASKDELETEFIELD']="Vuoi cancellare questo campo?";
$lang['L_SQL_COMMANDS_IN']=" riga in ";
$lang['L_SQL_COMMANDS_IN2']="  sec. parsed.";
$lang['L_SQL_OUT1']="Eseguito";
$lang['L_SQL_OUT2']="Comandi";
$lang['L_SQL_OUT3']="C'erano";
$lang['L_SQL_OUT4']="Commenti";
$lang['L_SQL_OUT5']="Poiché il risultato contiene piu di 5000 righe, queste non sono visibili.";
$lang['L_SQL_SELECDB']="Seleziona database";
$lang['L_SQL_TABLESOFDB']="Tabelle del database";
$lang['L_SQL_EDIT']="edit";
$lang['L_SQL_NOFIELDDELETE']="Impossibile cancellare perchè una tabella deve avere almeno un campo.";
$lang['L_SQL_FIELDDELETE1']="Il campo";
$lang['L_SQL_DELETED']="è stato cancellato";
$lang['L_SQL_CHANGED']="è stato cambiato.";
$lang['L_SQL_CREATED']="è stato creato.";
$lang['L_SQL_NODEST_COPY']="Senza destinazione non si può copiare!";
$lang['L_SQL_DESTTABLE_EXISTS']="Tabella di destinazione già esistente!";
$lang['L_SQL_SCOPY']="La struttura della tabella `%s` e stata copiata in `%s`.";
$lang['L_SQL_TCOPY']="La tabella `%s` è stata copiata con dati in tabella `%s`.";
$lang['L_SQL_TABLENONAME']="La tabella ha bisogno di un nome!";
$lang['L_SQL_TBLNAMEEMPTY']="Il nome della tabella non deve essere vuoto!";
$lang['L_SQL_COLLATENOTMATCH']="Set di caratteri(Charset) ed assortimento(Collation) incompatibili!";
$lang['L_SQL_FIELDNAMENOTVALID']="Errore: nome del campo non valido";
$lang['L_SQL_CREATETABLE']="crea tabella";
$lang['L_SQL_COPYTABLE']="copia tabelle";
$lang['L_SQL_STRUCTUREONLY']="solo struttura";
$lang['L_SQL_STRUCTUREDATA']="Struttura e Dati";
$lang['L_SQL_NOTABLESINDB']="Non ci sono tabelle nel database";
$lang['L_SQL_SELECTTABLE']="Seleziona tabella";
$lang['L_SQL_SHOWDATATABLE']="Guarda dati della tabella";
$lang['L_SQL_TBLPROPSOF']="Proprietà della tabella da";
$lang['L_SQL_EDITFIELD']="Edit campo";
$lang['L_SQL_NEWFIELD']="Nuovo campo";
$lang['L_SQL_INDEXES']="Indice";
$lang['L_SQL_ATPOSITION']="inserire nella posizione";
$lang['L_SQL_FIRST']="prima";
$lang['L_SQL_AFTER']="dopo";
$lang['L_SQL_CHANGEFIELD']="cambia campo";
$lang['L_SQL_INSERTFIELD']="inserisci campo";
$lang['L_SQL_INSERTNEWFIELD']="inserisci nuovo campo";
$lang['L_SQL_TABLEINDEXES']="Indice della tabella";
$lang['L_SQL_ALLOWDUPS']="Duplicati permessi";
$lang['L_SQL_CARDINALITY']="Cardinalità";
$lang['L_SQL_TABLENOINDEXES']="La tabella non contiene l`indice";
$lang['L_SQL_CREATEINDEX']="crea nuovo indice";
$lang['L_SQL_WASEMPTIED']="è stato svuotato";
$lang['L_SQL_RENAMEDTO']="è stato rinominato in";
$lang['L_SQL_DBCOPY']="Il contenuto del database `%s` è stato copiato nel database `%s`.";
$lang['L_SQL_DBSCOPY']="La struttura del database `%s` è stata copiata nel database `%s`.";
$lang['L_SQL_WASCREATED']="stato creato";
$lang['L_SQL_RENAMEDB']="Rinomina database";
$lang['L_SQL_ACTIONS']="Azioni";
$lang['L_SQL_CHOOSEACTION']="Seleziona azione";
$lang['L_SQL_DELETEDB']="Cancella database";
$lang['L_SQL_EMPTYDB']="Svuota database";
$lang['L_SQL_COPYDATADB']="Copia l`intero database in";
$lang['L_SQL_COPYSDB']="Copia struttura in database";
$lang['L_SQL_IMEXPORT']="Importa / Esporta";
$lang['L_INFO_RECORDS']="Record";
$lang['L_NAME']="Nome";
$lang['L_ASKTABLEEMPTYKEYS']="Vuoi svuotare la tabella `%s` e cancellare l`indice?";
$lang['L_EDIT']="edit";
$lang['L_DELETE']="elimina";
$lang['L_EMPTY']="svuota";
$lang['L_EMPTYKEYS']="svuota e cancella l`indice";
$lang['L_SQL_TABLEEMPTIED']="La tabella `%s` e stata svuotata.";
$lang['L_SQL_TABLEEMPTIEDKEYS']="La tabella `%s` è stata svuotata e l`ìndice è stato cancellato.";
$lang['L_SQL_LIBRARY']="SQL-Library";
$lang['L_SQL_ATTRIBUTES']="Attributi";
$lang['L_SQL_UPLOADEDFILE']="File caricato: ";
$lang['L_SQL_IMPORT']="Import del database `%s`";
$lang['L_EXPORT']="Esporta";
$lang['L_IMPORT']="Importa";
$lang['L_IMPORTOPTIONS']="Opzioni di importazione";
$lang['L_CSVOPTIONS']="Opzioni-CSV";
$lang['L_IMPORTTABLE']="Importa nella tabella";
$lang['L_NEWTABLE']="tabella nuova";
$lang['L_IMPORTSOURCE']="Sorgente di importazione";
$lang['L_FROMTEXTBOX']="dal campo testo";
$lang['L_FROMFILE']="dal file";
$lang['L_EMPTYTABLEBEFORE']="Svuota prima la tabella";
$lang['L_CREATEAUTOINDEX']="Creare indice automatico";
$lang['L_CSV_NAMEFIRSTLINE']="nome del campo nella prima riga";
$lang['L_CSV_FIELDSEPERATE']="Campi separati con";
$lang['L_CSV_FIELDSENCLOSED']="Campi inclusi in";
$lang['L_CSV_FIELDSESCAPE']="Campi sfuggiti da";
$lang['L_CSV_EOL']="Linee separate con";
$lang['L_CSV_NULL']="Cambia ZERO con";
$lang['L_CSV_FILEOPEN']="aprire file CSV";
$lang['L_IMPORTIEREN']="importare";
$lang['L_SQL_EXPORT']="Esportazione del database `%s`";
$lang['L_EXPORTOPTIONS']="Opzioni di esportazione";
$lang['L_EXCEL2003']="Excel 2003";
$lang['L_SHOWRESULT']="Visualizzare il risultato";
$lang['L_SENDRESULTASFILE']="Inviare risultato come file";
$lang['L_EXPORTLINES']="<strong>%s</strong> righe da esportare";
$lang['L_CSV_FIELDCOUNT_NOMATCH']="La quantità dei campi della tabella non coincide con i dati da importare (%d al posto di %d).";
$lang['L_CSV_FIELDSLINES']="%d campi trovati, totale %d righe";
$lang['L_CSV_ERRORCREATETABLE']="Errore nella creazione della tabella `%s` !";
$lang['L_FM_UPLOADFILEREQUEST']="Scegli un file.";
$lang['L_CSV_NODATA']="File da importare non trovato!";
$lang['L_SQLLIB_GENERALFUNCTIONS']="funzioni generali";
$lang['L_SQLLIB_RESETAUTO']="ripristina autoincremento";
$lang['L_SQLLIB_BOARDS']="Board";
$lang['L_SQLLIB_DEACTIVATEBOARD']="disattiva Board";
$lang['L_SQLLIB_ACTIVATEBOARD']="attivare Board";
$lang['L_SQL_NOTABLESSELECTED']="Non ci sono tabelle selezionate !";
$lang['L_TOOLS']="Tools";
$lang['L_TOOLS_TOOLBOX']="Scegliere database / Funzione database / Importa e Esporta ";
$lang['L_SQL_OPENFILE']="aprire file - SQL";
$lang['L_SQL_OPENFILE_BUTTON']="Caricare";
$lang['L_MAX_UPLOAD_SIZE']="Grandezza massima del file";
$lang['L_SQL_SEARCH']="Ricerca";
$lang['L_SQL_SEARCHWORDS']="Parola(e) di ricerca";
$lang['L_START_SQL_SEARCH']="esegui ricerca";
$lang['L_RESET_SEARCHWORDS']="resetta ricerca";
$lang['L_SEARCH_OPTIONS']="Opzione di ricerca";
$lang['L_SEARCH_RESULTS']="La ricera di \"<b>%s</b>\" nella tabella \"<b>%s</b>\" ha portato al seguente risultato";
$lang['L_SEARCH_NO_RESULTS']="La ricera \"<b>%s</b>\" nella tabella \"<b>%s</b>\" non ha prodotto risultati!";
$lang['L_NO_ENTRIES']="La tabella \"<b>%s</b>\" è vuota.";
$lang['L_SEARCH_ACCESS_KEYS']="Sfogliare: avanti=ALT+V, indietro=ALT+C";
$lang['L_SEARCH_OPTIONS_OR']="una colonna deve contenere almeno una parola di ricerca";
$lang['L_SEARCH_OPTIONS_CONCAT']="un record deve contenere tutte le parole di ricerca, però possono essere in colonne diverse (Calcolo intensivo!)";
$lang['L_SEARCH_OPTIONS_AND']="una colonna deve contenere tutte le parole di ricerca";
$lang['L_SEARCH_IN_TABLE']="cerca nelle tabelle";
$lang['L_SQL_EDIT_TABLESTRUCTURE']="Edit struttura tabelle";
$lang['L_DEFAULT_CHARSET']="Set di caretteri standard";
$lang['L_TITLE_KEY_PRIMARY']="Chiave primaria";
$lang['L_TITLE_KEY_UNIQUE']="Chiave unica";
$lang['L_TITLE_INDEX']="Indice";
$lang['L_TITLE_KEY_FULLTEXT']="Chiave testo pieno";
$lang['L_TITLE_NOKEY']="Nessuna chiave";
$lang['L_TITLE_SEARCH']="Cerca";
$lang['L_TITLE_MYSQL_HELP']="Documentazione MySQL";
$lang['L_TITLE_UPLOAD']="Carica dati-SQL";
$lang['L_PRIMARYKEY_DELETED']="Chiave primaria cancellata";
$lang['L_PRIMARYKEY_NOTFOUND']="Chiave primaria non trovata";
$lang['L_PRIMARYKEYS_CHANGED']="Chiave primaria cambiata";
$lang['L_PRIMARYKEYS_CHANGINGERROR']="Errore nel cambiare della chiave primaria";
$lang['L_SQL_VIEW_COMPACT']="Visualizza: compatto";
$lang['L_SQL_VIEW_STANDARD']="Visualizza: normale";
$lang['L_FIELDS_OF_TABLE']="Campi della tabella";
$lang['L_ENGINE']="Engine";
$lang['L_USERNAME']="Username";
$lang['L_PASSWORD']="Password";
$lang['L_PASSWORD_REPEAT']="Password (repeat)";
$lang['L_INFO_SIZE']="Grandezza";
$lang['L_TABLE_TYPE']="Tipo";
$lang['L_KEY_DELETED']="Index deleted";
$lang['L_KEY_DELETEERROR']="Error deleting index";
$lang['L_KEY_ADDED']="Index added";
$lang['L_KEY_ADDERROR']="Error adding index";


?>
